Word Count
==========

Counts the number of words in the specified string.

Based on the regexes / logic from Countable.js:

https://github.com/RadLikeWhoa/Countable

(recommended to use this function for back-end validation, in conjunction with Countable.js for a front-end live word count).
